% Nonlinear least squares with use of matlab's lsqcurvefit
% ydata is here zeros and xdata is the V/V0 and p

function K = lsq_CaO()
clear all
clc
x0 = [150 4 -0.0034]; % Guesses

[p, VdivV0,len] = pvdata_CaO();
xdata = [VdivV0', p']';
ydata = zeros(size(xdata));
n = length(xdata)/2;
m = length(xdata);
%------------------------------------------------------------------------
% Making a vector, len2, which contains the number of measuring points in
% each series
len2 = zeros(1, length(len)+1);
for i = 2:length(len2)
  len2(i) = sum(len(1:i-1));
end

% Gives the extra option parameters, param, through a struct array
param = struct('len', len2);
f = @(x,xdata)newcurve_res_cao(x,xdata,param);

% Calling the function lsqcurvefit
x = lsqcurvefit(f,x0,xdata,ydata);
fprintf('K01 =%g;\n', x(1));
fprintf('K02 =%g;\n', x(2));
fprintf('K03 =%g;\n', x(3));
K = x;
%------------------------------------------------------------------
% Plotting the residual plot and getting the mean for each series
[F, mean] = newcurve_res_cao(x, xdata,param);
subplot(2,1,1)
figure(1);

% Plotting all the experimental series
marker = ['*', 'p', 'o', '+', 'x', 's', 'd', 'v']';
hold on
for i = 1:length(len2)-1
plot(xdata(n+1+len2(i):n+len2(i+1)), F(1+len2(i):len2(i+1)), marker(i))
end
hold off

%------------------------------------------------------------------
% Making a contour plot for K02 and K03 to find if a minimum exists, and if
% so where it exists
K01 = x(1);
K02 = linspace(0,40,100);
K03 = linspace(-0.50,0.50,100);
Y = zeros(length(K02), length(K03));
for i = 1:length(K02)
    for j = 1:length(K03)
        k02 = K02(i);
        k03 = K03(j);
        a = k02/(2*K01)*(1+sqrt(1-4*k03*K01/(k02^2)));
        b = k02/K01-a;
        y = (log(xdata(1:n)) + 1/(K01*(a-b))*log((1+a*xdata(n+1:m))./(1+b*xdata(n+1:m))));
        Y(i,j) = sqrt(y'*y);
    end
end
Y(Y>3*min(min(Y))) = NaN;

% Plotting the contour plot
subplot(2,1,2)
contour(Y)

figure(2)
plot(p, VdivV0, '*');