% Comparison of the p-s EoS versus experimental data

clear all
close all
clc

K01 =160.123;
K02 =3.93;
V0 = 11.25; % cm^3/mol
gamma0 = 1.49; % Speziale 2001
theta = 743*0.75;
N = 2*6.023*10^-23;
kb = 1.38*10^23;
Tref = 298;

beta = 0.85;

% T = (0:5:1200)';
% p = 0;
Temp = [298,1100];
p = (0:0.5:220)';
colors = char('blue','r','cyan','green','yellow','magenta');
for i = 1:length(Temp)
    T = Temp(i);
psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)))/1000;
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; % Calculated at Tref, independent of T
K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); % Pressure derivative of 
                                           % bulk modulus
Vsp = V0.*exp(beta./((1-beta)*K02));

V01 = Vsp*exp(-kappa/(1-beta).*(p-psp).^(1-beta));
V0T = Vsp*exp(-kappa/(1-beta).*(-psp).^(1-beta));
V0ref = Vsp*exp(-kappa/(1-beta).*(-pspTref).^(1-beta));

V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

VdivV0 = V/V0ref;

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000; % K^-1

% Murnaghan
KMur = K01+K02*p;
aMur = (gamma0./(V0.*KMur)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000;
aKT =-aMur.*KMur; % GPaK^(-1)
Pth = aKT.*(T-Tref);
p0 = 0.0001;
pmur = p+Pth;
VdivV0Mur = ((K01+K02*pmur)./(K01+K02*p0)).^(-1/K02);
%-------------------------------------------------------------------------
% Experimental data for alpha
h1 = load('Speziale_and_Zha_etal_2001.txt');
pexp = h1(:,3);
VdivV0exp= h1(:,4);
h2 = load('fei_1999.txt');
pexp2 = h2(:,3);
VdivV0exp2 = h2(:,4)/h2(1,4);

%-------------------------------------------------------------------------
% Plotting
axis([0 25 0.85 1.1])
hp = figure(1);
hold on
xlab = xlabel('p [GPa]');
ylabel('V/V_0')    
    plot(p,VdivV0,colors(i), 'linewidth', 1.5)
end
plot(pexp2,VdivV0exp2,'*')
legend('298 K','1100 K','Exp. data');
% set(gca,'FontSize',10)
set(hp,'WindowStyle','docked')
set(hp,'PaperpositionMode','auto')
saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\pvt_MgO','epsc')