% MgO heat capacity as a function of temperature
clear all
close all
clc

% MgO
K01 =160.123e9; % Pa = J/m^3
K02 =3.93;
V0 = 11.25e-6; % m^3/mol
gamma0 = 1.49; % Speziale 2001
theta = 743*0.75;
N = 2*6.023*10^-23;
Tref = 298;
Mw = 40.31;

beta = 0.85;
kb = 1.38e23;
pres = [0.0001 5 10 20 30]*10^9;

%-------------------------------------------------------------------------
% Data from JANAF
A = 47.25995;
B = 5.681621;
C = -0.872665;
D = 0.104300;
E = -1.053955;
TJA = (298:1:3050);
TJ = TJA/1000;
CpJanaf = A + B*TJ + C*(TJ.^2) + D*(TJ.^3) + E./(TJ.^2);
%-------------------------------------------------------------------------
% Experimental heat capacity
addpath(cd('..\'));
h1 = load('barron_and_berg_etal_1959_cp.txt');
cp1 = h1(:,3)*4.184;
Texp = h1(:,2);
Cpexp = cp1;

%------------------------------------------------------------------------
T = [Texp;TJA'];
colors = char('blue','r','cyan','green','magenta');
marker = char('d');
for i = 1:length(pres)
p = pres(i);
psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)));
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)));
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)));
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; % Utregna ved Tref, independent of T

K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); % pressure deriv, bulk modulus

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2); % K^-1
Cpps = (3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2).*(1+T.*a.*gamma0);

Vsp = V0.*exp(beta./((1-beta)*K02)); % Vsp is evaluated at reference state
V01 = Vsp*exp(-kappa/(1-beta).*(-psp).^(1-beta)); % V(p=0)
V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

% Chemical potential
k = kappa;
a2 = -k/(1-beta);
b = psp;
c = 1-beta;
p0 = 0;
my1 = (b-p).*(-a2.*(p-b).^c).^(-1/c);
myg = (gammainc(-a2.*(p-b).^c,1/c,'upper')).*gamma(1/c);
my = Vsp.*my1.*myg./c;

my10 = (b-p0).*(-a2*(p0-b).^c).^(-1/c);
myg0 = (gammainc(-a2*(p0-b).^c,1/c,'upper'))*gamma(1/c);
my0 = Vsp.*my10.*myg0./c;

mytot  = my-my0; % J/mol
mym    = my*Mw;  % J/g
mytotm = mytot*Mw;%J/g 

d1 = central_diff(mytot,T);
d2 = central_diff(d1,T);
%----------------------------------------------------------------------
% Plotting 
hp = figure(1);
hold on
xlabel('Temperature [K]','fontsize',10)
ylabel('C_p [J/(K, mol)]','fontsize',10)
Cpcalc1 = -Texp.*d2(1:length(Texp))+Cpexp;
Cpcalc2 = -TJA'.*d2(length(Texp)+1:end)+CpJanaf';
h1(i)=plot(Texp,Cpcalc1, marker);
h2(i)=plot(TJA',Cpcalc2);
set(h1(i),'color', colors(i), 'MarkerSize', 4)
set(h2(i), 'color', colors(i), 'Linewidth', 1.5)
hAnnotation = get(h1(i),'Annotation');
hLegendEntry = get(hAnnotation','LegendInformation');
set(hLegendEntry,'IconDisplayStyle','off')
end

axis([0 3000 -20 60])
leg = legend('0.0001 GPa','1000 GPa','10 GPa','20 GPa','30 GPa');
set(leg,'Location','SouthEast','fontsize',10)
set(hp,'WindowStyle','docked')
set(gca,'fontsize',10)
set(hp,'PaperpositionMode','auto')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\MgO_Cpexp','epsc')