% Pseudo-Spinodal EoS, predictions of alpha comparison with exp. data

clear all
close all
clc

% MgO
K01 =160.123;
K02 =3.93;
V0 = 11.25; % cm^3/mol
gamma0 = 1.49; % Speziale 2001
theta = 743*0.75;
N = 2*6.023*10^-23;
Tref = 298;

beta = 0.85;
A = beta*K01/K02;
B = K01*(1-beta);
C = A^beta;
D = 1/(1-beta);
kb = 1.38*10^23;
T = (0:1:3000)';
p = 0;

psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)))/1000;
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; % Calculated at Tref, independent of T
K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); % Pressure derivative of 
                                           % bulk modulus
Vsp = V0.*exp(beta./((1-beta)*K02));

V01 = Vsp*exp(-kappa/(1-beta).*(p-psp).^(1-beta));
V0T = Vsp*exp(-kappa/(1-beta).*(-psp).^(1-beta));
V0ref = Vsp*exp(-kappa/(1-beta).*(-pspTref).^(1-beta));

V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

VdivV0T = V/V0T;

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000; % K^-1
%-------------------------------------------------------------------------
% Experimental data for alpha
h1 = load('anderson_and_zou_1989.txt');
Texp = h1(:,2);
alpha= h1(:,3)*10^-6;

%-------------------------------------------------------------------------
% Murnaghan
Kmur = K01+K02*p;
aMur = (gamma0./(V0.*Kmur)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000;

% Calculating the isentropic bulk moduls
Ks = K_spi.*(1+a.*gamma0.*T);

% Plotting
hold on
hp = figure(1);
axis([0 3000 0 0.00008])
xlabel('Temperature [K]')
ylabel('\alpha{} [K^{-1}]')
plot(T,a,'linewidth',1.5)
plot(T,aMur, 'r','linewidth',1.5)
plot(Texp,alpha,'*')
hold off
set(hp,'WindowStyle','docked')
set(hp,'PaperpositionMode','auto')
leg = legend('Pseudo-spinodal','First order Murnaghan', 'Exp. data');
set(leg,'Location', 'SouthEast')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\alphaTexp_MgO','epsc')