% Pseudo-Spinodal equation 
% Prediction for the p-V-T surface compared to exp.data 

clear all
close all
clc

K01 = 24.38;
K02 = 5.0;
V0 = 27;
gamma0 = 1.59;
theta = 241;
N = 2*6.023*10^-23;
Tref = 298;

beta = 0.85;

kb = 1.38*10^23;
Temp = [298,373,473,573,673,773];
p = (0:0.5:30)';
colors = char('blue','r','cyan','green','yellow','magenta');
for i = 1:length(Temp)
    T = Temp(i);
psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)))/1000;
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; 

K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); 


V01 = exp(-kappa/(1-beta).*(p-psp).^(1-beta));
V0T = exp(-kappa/(1-beta).*(-psp).^(1-beta)); 
V0ref =exp(-kappa/(1-beta).*(-pspTref).^(1-beta)); 

Vsp = V01.*exp(beta./((1-beta)*K_spi2));

V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

VdivV0 = V/V0ref;

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000; % K^-1

%-------------------------------------------------------------------------
% Experimental data
h1 = load('boehler_and_kennedy_1980b.txt');
pexp = h1(:,3);
VdivV0exp= h1(:,4);
%-------------------------------------------------------------------------
% Plotting
axis([0 3.5 0.9 1.1])
hp = figure(1);
hold on
xlabel('p [GPa]')
ylabel('V/V_0')    
    plot(p,VdivV0,colors(i),'linewidth',1.5);
end
plot(pexp,VdivV0exp,'*');
legend('298 K','373 K','473 K','573 K','673 K', '773 K','Exp. data')
set(hp,'WindowStyle','docked')
set(hp,'PaperpositionMode','auto')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\pvt_NaCl','epsc')