% Pseudo-Spinodal equation 
% Predictions for alpha compared to exp.data

clear all
close all
clc

% NaCl
K01 =24.3804;
K02 =4.99712;
V0 = 27;
gamma0 = 1.59;
theta = 240;
N = 2*6.023*10^-23;
Tref = 298;
beta = 0.85;

kb = 1.38*10^23;
% T = (0:1:1000)';
% p = 0;
T = 300;
p = (0:0.5:30)';


psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)))/1000;
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; 

K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); 


V01 = exp(-kappa/(1-beta).*(p-psp).^(1-beta));
V0T = exp(-kappa/(1-beta).*(-psp).^(1-beta)); 
V0ref =exp(-kappa/(1-beta).*(-pspTref).^(1-beta)); 

Vsp = V01.*exp(beta./((1-beta)*K_spi2));

V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

VdivV0 = V/V0ref;

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000; % K^-1
%-------------------------------------------------------------------------
% Experimental data for alpha
h1 = load('boehler_and_kennedy_1980.txt');
pexp = h1(:,2);
alphap= h1(:,3)*10^-4;

h2 = load('anderson_1995.txt');
Texp = h2(:,2);
alphaT= h2(:,3)*10^-5;
%-------------------------------------------------------------------------
% Murnaghan
Kmur = K01+K02*p;
aMur = (gamma0./(V0.*Kmur)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000;
%-------------------------------------------------------------------------

% Plotting
hp = figure(1);
hold on
% title('Thermal expansion coeffisient versus pressure for NaCl')
xlabel('p [GPa]')
ylabel('\alpha{} [K^{-1}]')
plot(p,a,'linewidth',1.5)
plot(pexp,alphap,'*')
plot(p,aMur,'r','linewidth',1.5)
set(hp,'WindowStyle','docked')
set(hp,'PaperpositionMode','auto')
leg = legend('Pseudo-spinodal','First order Murnaghan', 'Exp. data');
set(leg,'Location','NorthEast')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\alphaPexp_NaCl','epsc')
% 
% title('Thermal expansion coeffisient versus temperature for NaCl')
% xlabel('Temperature [K]')
% axis([0 1000 0 0.00025])
% ylabel('\alpha{} [K^{-1}]')
% plot(T,a,'linewidth',1.5)
% plot(T,aMur,'r','linewidth',1.5)
% plot(Texp,alphaT,'*')
% leg = legend('Pseudo-spinodal','First order Murnaghan', 'Exp. data');
% set(leg,'Location','SouthEast')
% set(hp,'WindowStyle','docked')
% set(hp,'PaperpositionMode','auto')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\alphaTexp_NaCl','epsc')