% Pseudo-Spinodal equation 
% Predictions for alpha as a function of pressure for NaCl

clear all
close all
clc

% NaCl
K01 =24.3804;
K02 =4.99712;
V0 = 27;
gamma0 = 1.59;
theta = 240;
N = 2*6.023*10^-23;
Tref = 298;

beta = 0.85;
A = beta*K01/K02;
B = K01*(1-beta);
C = A^beta;
D = 1/(1-beta);
kb = 1.38*10^23;

p = (0:1:50);
Temp = [200,298.15,500,750,1000];
colors = char('blue','r','cyan','green','magenta');
for i = 1:length(Temp)
T = Temp(i);
psp298 = -K01/K02*0.85;
psp0 = psp298 - (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
pspTref = psp0 + (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./Tref)-1)))/1000;
ha = (gamma0/V0*3*N*kb*theta*(0.5+1./(exp(theta./T)-1)))/1000;
psp = psp0 + ha;
kappa = ((-pspTref).^beta)/K01; 

K_spi  = (1./kappa).*(p-psp).^beta; % Bulk modulus
K_spi2 = (beta./kappa).*(p-psp).^(beta-1); 


V01 = exp(-kappa/(1-beta).*(p-psp).^(1-beta));
V0T = exp(-kappa/(1-beta).*(-psp).^(1-beta)); 
V0ref =exp(-kappa/(1-beta).*(-pspTref).^(1-beta)); 

Vsp = V01.*exp(beta./((1-beta)*K_spi2));

V = Vsp.*exp(-kappa/(1-beta)*(p-psp).^(1-beta));

VdivV0T = V/V0T;

a = (gamma0./(V0.*K_spi)*3*N*kb.*((theta./T).^2)).*exp(theta./T)./((exp(theta./T)-1).^2)/1000; % K^-1

%-------------------------------------------------------------------------
% Calculating the isentropic bulk moduls
Ks = K_spi.*(1+a.*gamma0.*T);

% Plotting
hold on
axis([0 50 0 0.00025])
hp = figure(1);
% title('Thermal expansion coeffisient versus pressure for MgO')
xlabel('Pressure [GPa]','fontsize',12)
ylabel('\alpha [K^{-1}]','fontsize',12)
plot(p,a,colors(i),'linewidth',1.5)
end
leg = legend('200 K','298.15 K','500 K','750 K','1000 K');
set(leg,'Location','NorthEast','fontsize',10)
set(hp,'WindowStyle','docked')
set(gca,'fontsize',12)
set(hp,'PaperpositionMode','auto')
% saveas(1,'C:\Users\Stig-Erik\NTNU\Master\Latex\alphaP_NaCl','epsc')