% Test of bulk modulus for the four different isothermal EOS
% versus the second order Murnaghan with uncertainty

clc
clear all
close all

V_V0 = 0.1:0.0001:1;
X = (V_V0).^(1/3);
scale = linspace(-3,3,1000);
Nsolids = 6;

% Values given for MgCO3 from lsq and firstdiff
t1='MgCO_3';
K1(1) =112.436;
K2(1) =4.76634;
K3(1) =-0.0270562;
std1(1,:) = [0.000043; 0.000440; 0.007388];
std2(1,:) = [0.115360; 0.429741; -0.026252];
std3(1,:) = [-3.049675; 0.816764; -0.030929];
pmaxi(1,:) = 39.7*ones(1,length(scale));

% Values given for NaCl from lsq and firstdiff
t2 = 'NaCl';
K1(2) =24.3804;
K2(2) =4.99712;
K3(2) =-0.0486765;
std1(2,:) = [0.000025; 0.000157; 0.002096];
std2(2,:) = [0.035737; 0.086438; -0.006905];
std3(2,:) = [-0.896211; 0.369168; -0.017092];
pmaxi(2,:) = 37*ones(1,length(scale));


% Values given for SiO2 from lsq
t3 = 'SiO_2';
K1(3) =38.5545;
K2(3) =5.44556;
K3(3) =-0.155289;
std1(3,:) = [0.000913; 0.003420; 0.021745];
std2(3,:) = [0.214945; 0.376384; -0.068223];
std3(3,:) = [-2.995555; 1.685451; -0.139257];
pmaxi(3,:) = 15.3*ones(1,length(scale));

% Values given for CaO from lsq
t4 = 'CaO';
K1(4) =109.401;
K2(4) =4.92936;
K3(4) =-0.0276964;
std1(4,:) = [0.000002; 0.000030; 0.000988];
std2(4,:) = [0.026185; 0.182513; -0.005618];
std3(4,:) = [-4.898921; 0.702416; -0.013587];
pmaxi(4,:) = 65.2*ones(1,length(scale));

% Values given for Al2O3 from lsq
t5 = 'Al_2O_3';
K1(5) =269.773;
K2(5) =4.35411;
K3(5) =-0.0130543;
std1(5,:) = [0.000000; 0.000012; 0.000784];
std2(5,:) = [0.009872; 0.154277; -0.002390];
std3(5,:) = [-9.097483; 0.582079; -0.005196];
pmaxi(5,:)=144.7670*ones(1,length(scale));

% Values given for MgO from lsq
t6 = 'MgO';
K1(6) =160.123;
K2(6) =3.93044;
K3(6) =-0.00269764;

std1(6,:) = [0.000001; 0.000021; 0.000802];
std2(6,:) = [0.008561; 0.076362; -0.002009];
std3(6,:) = [-2.421412; 0.371368; -0.003795];
pmaxi(6,:) = 121.752*ones(1,length(scale));

%------------------------------------------------------------------------
% Calculating the parameters with standard deviation
%------------------------------------------------------------------------
titles = {t1, t2, t3, t4, t5, t6};

for i = 1:Nsolids
figure(i)
std = [std1(i,:);std2(i,:);std3(i,:)];
% std = abs(std);
K01 = K1(i);
K02 = K2(i);
K03 = K3(i);
pmax = pmaxi(i,:);
title(titles(i));
%------------------------------------------------------------------------

%Murnaghan
K_Mur = K01*X.^(-3*K02);
p_Mur = K01/K02*(X.^(-3*K02)-1);

%Birch-Murnaghan
K_Bir = 0.5*K01*(7*X.^(-7)-5*X.^(-5))+3/8*K01*(K02-4)*(9*X.^(-9)-14*X.^(-7)+5*X.^(-5)); %Checked
p_Bir = 3/2*K01*(X.^(-7)-X.^(-5)).*(1+3/4*(K02-4)*(X.^(-2)-1));

%Vinet
K_Vin = K01*X.^(-2).*(1+(3/2*(K02-1)*X + 1).*(1-X)).*exp(3/2*(K02-1)*(1-X));
p_Vin = 3*K01*(1-X)./(X.^2).*exp(3/2*(K02-1)*(1-X));

%Pseudo-Spinodal
beta = 0.85;
A = beta*K01/K02;
B = K01*(1-beta);
C = A^beta;
D = 1/(1-beta);
p_Spi = (((A-log(V_V0)*B)/C).^(D))-A;

kappa = (A^beta)/K01;
E = beta/((1-beta)*K02);
F = kappa/(1-beta);
pspi = (((E-log(V_V0))/F).^D) - A;
K_Spi = 1/kappa*(pspi+A).^beta;

% Our equation
a = K02/(2*K01)*(1+sqrt(1-4*K03*K01/(K02^2)));
b = K02/K01-a;
c = K01*(a-b);
p_Our = 0:1:500;
K_Our = K01 + K02*p_Our + K03/2*p_Our.^2;
Y_Our   = ((K_Our - K02*p_Our)/K01)';

% Making residuals
Y_Mur = (K_Mur - K02*p_Mur)/K01*1.0000000000001;% Remove roughness
Y_Bir = (K_Bir - K02*p_Bir)/K01;
Y_Vin = (K_Vin - K02*p_Vin)/K01;
Y_Spi = (K_Spi - K02*p_Spi)/K01;

% Plotting
colors = [([0.75 0.75 0.75]);([0.8 0.8 0.8]);([0.65 0.65 0.65])];
location = [([.4,.7,.4,.2]);([.47,.48,.4,.2]);([.47,.48,.4,.2]);([.43,.7,.4,.2]);([.17,.15,.4,.2]);([.165,.15,.4,.2])]; %([left,bottom,width,height])
axis([0 200 -3 3])
xlabel('Pressure [GPa]')
ylabel('(K - (K_0''p))/K01 [-]')
hold on
for j = 1:length(std)
stdK01=std(j,1);
stdK02=std(j,2);
stdK03=std(j,3);
K01_u = K01 + stdK01;
K02_u = K02 + stdK02;
K03_u = K03 + stdK03;
K01_l = K01 - stdK01;
K02_l = K02 - stdK02;
K03_l = K03 - stdK03;
K_Our_u = K01_u + K02_u*p_Our + K03_u/2*p_Our.^2;
K_Our_l = K01_l + K02_l*p_Our + K03_l/2*p_Our.^2;
Y_Our_u = ((K_Our_u - K02*p_Our)/K01)';
Y_Our_l = ((K_Our_l - K02*p_Our)/K01)';
Y_Our_p = max(Y_Our_u,Y_Our_l);
Y_Our_m = min(Y_Our_u,Y_Our_l);
h1 =jbfill(p_Our,Y_Our_p',Y_Our_m',[0.6 0.8 0.8]);
end

hold on
axis([0 200 -2 2])

h3 = plot(p_Mur,Y_Mur, 'color',[0,0.8,0],'LineWidth',1.5);
h4 = plot(p_Bir,Y_Bir, 'b','LineWidth',1.5);
h5 = plot(p_Vin,Y_Vin, 'r','LineWidth',1.5);
h6 = plot(p_Spi,Y_Spi, 'magenta','LineWidth',1.5);
h7 = plot(pmax,scale, '--black');
h_legend = legend([h1, h3, h4, h5, h6, h7],...
    {'Second order Murnaghan with uncertainty','Murnaghan', 'Birch', 'Vinet', 'Pseudo-spinodal', 'Maximum experimental pressure'});
set(h_legend,'FontSize',8,'Position',location(i,:));
filename=sprintf('bulk%g.svg',i);
plot2svg(filename)

hold off
end