% Testing the analytical differentiation versus numerical differentiation

clc
clear all
close all

% addpath('Al2O3')
addpath('MgO')
% addpath('NaCl')
% addpath('SiO2')
% addpath('CaO')
% addpath('MgCO3')

% Giving the values for each of the parameters
[p, VdivV0,len] = pvdata_mgo();
x = lsq_mgo();
theta_opt = x;
xdata = [VdivV0',p']';
dtheta = [10^-4 10^-6 10^-8];

dfdtheta = gradient(x, xdata);

% Calculating and testing the analytical differentiation versus numerical
% differentiation
gradnum = numdiff(x,xdata,dtheta);

% Printing 
fprintf('dfdtheta(analytic)  = %f\n', dfdtheta)
fprintf('dfdtheta(numerical) = %f\n', gradnum)
fprintf('ratio = %f\n', dfdtheta./gradnum)
disp('')
J = numdiff(x,xdata,dtheta);
H = numdiff2(x,xdata,dtheta);
disp('H = ')
disp(H);

[Q, L] = eig(inv(H));
covari = inv(H);
lambda = Q'*inv(H)*Q; % Diagonal matrix equal to L

% s^2 is a estimator for the variance
% F is the evaluated implicit function 
F = returnf(x,xdata);
% s2 = 1/((length(F)-length(x)))*(F'*F); % Residual sum of squares div degrees 
% of freedom or estimate of error variance

B = Q*sqrt(L);

Imat = inv(B)*Q*L*Q'*inv(B)';

k = x*(Q*diag(1./(sqrt(diag(L)))));
k_opt = x*(Q*diag(1./(sqrt(diag(L)))));
dtheta = zeros(3,3);
dtheta(1,:)=B*([1 0 0])';
dtheta(2,:)=B*([0 1 0])';
dtheta(3,:)=B*([0 0 1])';

disp(dtheta)

%------------------------------------------------------------------
% Making a contour plot for k2 and k3 to find if a minimum exists, and if
% so where it exists
K01 = k_opt(1);
K02 = linspace(145,185,100);
K03 = linspace(-25,-65,100);
Y = zeros(length(K02), length(K03));
for i = 1:length(K02)
    for j = 1:length(K03)
        k01 = B(1,:)*[K01;K02(i);K03(j)];
        k02 = B(2,:)*[K01;K02(i);K03(j)];
        k03 = B(3,:)*[K01;K02(i);K03(j)];
        a = k02/(2*k01)*(1+sqrt(1-4*k03*k01/(k02^2)));
        b = k02/k01-a;
        y = (log(VdivV0) + 1/(k01*(a-b))*log((1+a*p)./(1+b*p)));
        Y(i,j) = sqrt(y'*y);
    end
end
Y(Y>3*min(min(Y))) = NaN;

% Plotting the contour plot
figure(4)
vector2 = 0:0.02:0.1;
contour(K03,K02,Y-min(min(Y)),vector2)
xlabel('\kappa{}_3')
ylabel('\kappa{}_2')
