% Making a function which return the first order derivative of F

function dfdtheta = gradient(x, xdata)

K01 = x(1);
K02 = x(2);
K03 = x(3);
n = length(xdata)/2;
m = length(xdata);
p = xdata(n+1:m);
VdivV0 = xdata(1:n);
gamma1 = K01;
gamma2 = 1/(2*K01)*(K02+sqrt(K02^2-4*K03*K01));
gamma3 = 1/(2*K01)*(K02-sqrt(K02^2-4*K03*K01));

% Calculating the implicit F function

F = log(VdivV0)+ 1/(K01*(gamma2-gamma3))*log((1+gamma2*p)./(1+gamma3*p));
an = length(F); % same length as p and VdivVo
Y = sqrt(F'*F); % Y = norm(F)

% Calculating the matrix dgamma/dtheta analytically
dgamma1dtheta1 = 1;
dgamma1dtheta2 = 0;
dgamma1dtheta3 = 0;

dgamma2dtheta1 = -1/(2*K01^2)*(K02+sqrt(K02^2-4*K03*K01))-K03/K01*(K02^2-4*K03*K01)^(-0.5);
dgamma2dtheta2 = 1/(2*K01)*(1+K02*(K02^2-4*K03*K01)^(-0.5));
dgamma2dtheta3 = -(K02^2-4*K03*K01)^(-0.5);

dgamma3dtheta1 = -1/(2*K01^2)*(K02-sqrt(K02^2-4*K03*K01))+K03/K01*(K02^2-4*K03*K01)^(-0.5);
dgamma3dtheta2 = 1/(2*K01)*(1-K02*(K02^2-4*K03*K01)^(-0.5));
dgamma3dtheta3 = (K02^2-4*K03*K01)^(-0.5);

dgammadtheta = [dgamma1dtheta1 dgamma1dtheta2 dgamma1dtheta3;
                dgamma2dtheta1 dgamma2dtheta2 dgamma2dtheta3;
                dgamma3dtheta1 dgamma3dtheta2 dgamma3dtheta3];
% Calculating the vector df/dgamma analytically

dfdgamma1 = -1/(K01^2*(gamma2-gamma3))*log((1+gamma2*p)./(1+gamma3*p));
dfdgamma2 = -1/(K01*(gamma2-gamma3)^2)*log((1+gamma2*p)./(1+gamma3*p))+1/(gamma1*(gamma2-gamma3))*p./(1+gamma2*p);
dfdgamma3 = 1/(K01*(gamma2-gamma3)^2)*log((1+gamma2*p)./(1+gamma3*p))-1/(gamma1*(gamma2-gamma3))*p./(1+gamma3*p);

dfdgamma = [dfdgamma1 dfdgamma2 dfdgamma3];

% Calculating the vector df/dtheta, which is the primary objective, analytically 
s = sqrt((F'*F));
dfdtheta = F'*dfdgamma*dgammadtheta/(Y)*1/(s)*((((an)/sqrt(2)))); 